WeakDevice

Struct WeakDevice 

pub struct WeakDevice { /* private fields */ }
Weak reference to the device. Must be upgraded to strong reference before use. Upgrade will fail if last strong reference to device was dropped.

Implementations

Source

impl WeakDevice

pub fn upgrade(&self) -> Option<Device>

Upgrades to strong reference.

pub fn is(&self, device: &Device) -> bool

Checks if this reference points to the same device.